note 53105 deleted from function.fsockopen by didou
| From: | didou@php.net | Date: | Mon, 18 Jun 2007 07:24:18 +0000 |
| Subject: | note 53105 deleted from function.fsockopen by didou | ||
| References: | 1 | Groups: | php.notes |
| Request: | Send a blank email to php-notes+get-127529@lists.php.net to get a copy of this message | ||
Note Submitter: mzvarik at gmail dot com
----
If you just want to get the page content it's better to use fopen instead of fsockopen... I did
a benchmark and it's faster... depends on how big is the content, getting it using fopen can be
sometimes even 2x faster.